@@ -87,7 +87,7 @@ changes_pattern = re.compile(r'\s(?P<files>\d+)\s+(files? changed),\s+(?P<insert
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.2'
     description = '`git log` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -110,7 +110,7 @@ def _process(proc_data: Dict) -> Dict:
 
         Dictionary. Structured data to conform to the schema.
     """
-    int_list = ['files_changed', 'insertions', 'deletions']
+    int_list = {'files_changed', 'insertions', 'deletions'}
 
     if 'date' in proc_data:
         ts = jc.utils.timestamp(proc_data['date'], format_hint=(1100,))
