@@ -1,9 +1,9 @@
 """jc - JSON Convert `mpstat` command output streaming parser
 
 > This streaming parser outputs JSON Lines (cli) or returns an Iterable of
-  Dictionaries (module)
+> Dictionaries (module)
 
-Note: Latest versions of `mpstat` support JSON output (v11.5.1+)
+> Note: Latest versions of `mpstat` support JSON output (v11.5.1+)
 
 Usage (cli):
 
@@ -101,7 +101,7 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.0'
+    version = '1.1'
     description = '`mpstat` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -124,14 +124,15 @@ def _process(proc_data: Dict) -> Dict:
 
         Dictionary. Structured data to conform to the schema.
     """
-    float_list = [
+    float_list = {
         "percent_usr", "percent_nice", "percent_sys", "percent_iowait", "percent_irq",
         "percent_soft", "percent_steal", "percent_guest", "percent_gnice", "percent_idle", "intr_s",
         "nmi_s", "loc_s", "spu_s", "pmi_s", "iwi_s", "rtr_s", "res_s", "cal_s", "tlb_s", "trm_s",
         "thr_s", "dfr_s", "mce_s", "mcp_s", "err_s", "mis_s", "pin_s", "npi_s", "piw_s", "hi_s",
         "timer_s", "net_tx_s", "net_rx_s", "block_s", "irq_poll_s", "block_iopoll_s", "tasklet_s",
         "sched_s", "hrtimer_s", "rcu_s"
-    ]
+    }
+
     for key in proc_data:
         if (key in float_list or (key[0].isdigit() and key.endswith('_s'))):
             proc_data[key] = jc.utils.convert_to_float(proc_data[key])
