@@ -13,7 +13,7 @@ Usage (cli):
 
     $ traceroute 1.2.3.4 | jc --traceroute
 
-    or
+or
 
     $ jc traceroute 1.2.3.4
 
@@ -122,7 +122,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.4'
+    version = '1.6'
     description = '`traceroute` and `traceroute6` command parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -164,6 +164,8 @@ SOFTWARE.
 
 RE_HEADER = re.compile(r'(\S+)\s+\((\d+\.\d+\.\d+\.\d+|[0-9a-fA-F:]+)\)')
 RE_PROBE_NAME_IP = re.compile(r'(\S+)\s+\((\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3}|[0-9a-fA-F:]+)\)+')
+RE_PROBE_IP_ONLY = re.compile(r'(\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})\s+([^\(])')
+RE_PROBE_IPV6_ONLY = re.compile(r'(([a-f0-9:]+:+)+[a-f0-9]+)')
 RE_PROBE_BSD_IPV6 = re.compile(r'\b(?:[A-Fa-f0-9]{1,4}:){7}[A-Fa-f0-9]{1,4}\b')
 RE_HOP = re.compile(r'^\s*(\d+)?\s+(.+)$')
 RE_PROBE_ASN = re.compile(r'\[AS(\d+)\]')
@@ -274,13 +276,21 @@ def _loads(data):
             probe_asn = None
 
         probe_name_ip_match = RE_PROBE_NAME_IP.search(hop_string)
+        probe_ip_only_match = RE_PROBE_IP_ONLY.search(hop_string)
         probe_bsd_ipv6_match = RE_PROBE_BSD_IPV6.search(hop_string)
-        if probe_name_ip_match:
+        probe_ipv6_only_match = RE_PROBE_IPV6_ONLY.search(hop_string)
+        if probe_ip_only_match:
+            probe_name = None
+            probe_ip = probe_ip_only_match.group(1)
+        elif probe_name_ip_match:
             probe_name = probe_name_ip_match.group(1)
             probe_ip = probe_name_ip_match.group(2)
         elif probe_bsd_ipv6_match:
             probe_name = None
             probe_ip = probe_bsd_ipv6_match.group(0)
+        elif probe_ipv6_only_match:
+            probe_name = None
+            probe_ip = probe_ipv6_only_match.group(1)
         else:
             probe_name = None
             probe_ip = None
@@ -331,8 +341,8 @@ def _process(proc_data):
 
         Dictionary. Structured to conform to the schema.
     """
-    int_list = ['hop', 'asn']
-    float_list = ['rtt']
+    int_list = {'hop', 'asn'}
+    float_list = {'rtt'}
 
     if 'hops' in proc_data:
         for entry in proc_data['hops']:
